#import "fontawesome.typ": *
#import "lib.typ": template, education_entry, work_entry, project, indent

#set page(margin: 1.75in)
#set par(leading: 0.5em, first-line-indent: 1.8em, justify: true)
#show raw: set text(font: "New Computer Modern Mono")
#show par: set block(spacing: 0.55em)
#show heading: set block(above: 2em, below: 1em)

#set list(indent: 1em)

// Change the theme color of the cv.
#let color = black
#let name = "Daniel Chen"

#let contact_data = (
  (
    service: fa[#globe],
    display: "eggworld.me",
    link: "https://eggworld.me"
  ),
  (
    service: fa[#github],
    display: "potatoeggy",
    link: "https://github.com/potatoeggy"
  ),
  (
    service: fa[#linkedin],
    display: "potatoeggy",
    link: "https://www.linkedin.com/in/potatoeggy/"
  ),
  (
    service: fa[#envelope],
    display: "daniel.chen1@uwaterloo.ca",
    link: "mailto://daniel.chen1@uwaterloo.ca"
  ),
)

#show: doc => template(name, contact_data, color, doc)

// MAIN CONTENT STARTS here

= Skills

#indent[
    *Languages*: Python, TypeScript/JavaScript, Rust, SQL, C++, Dart, Bash, Java, HTML, CSS \
    *Frameworks*: Node.js, Express, React, Next.js, Vue, Flutter, Qt, Prisma, Apollo, Axum, Diesel \
    *Tools*: Linux, Git, Docker, PostgreSQL, Redis, Kubernetes, AWS, GCP, OpenTelemetry, GraphQL
]

= Experience

#indent[
#work_entry(
  "Software Engineering Intern",
  "Dropbase",
  start_date: "May 2023", end_date: "Aug 2023",
  location: "Remote",
  tasks: (
    "Designed a type-safe ORM-style query builder to dynamically generate JSON forms based on external data",
    "Integrated Airtable and HubSpot APIs with the core product via AWS Lambda to automate data migration",
    "Refactored the frontend to use react-hook-form to aggregate and validate user input, improving DX",
    "Created a Pytest testing framework to verify core functionality across many different databases"
  )
)

#work_entry(
  "Backend Developer",
  "Hack the North",
  start_date: "Mar 2023", end_date: "present",
  location: "Waterloo, ON",
  tasks: (
    "Integrated OpenTelemetry and Grafana into a Kubernetes cluster to collect traces and improve observability",
    "Dynamically generated Apple Wallet URLs over Apollo Server and GraphQL for a registration ticket",
    "Increased API reliability with Redis Sentinel to automatically failover to backup Redis instances",
    "Slashed dev server reload time by 1500% by pre-transpiling GraphQL resolvers and offloading type-checking"
  )
)
]

= Projects

#indent[
#project("Mandown", "https://github.com/potatoeggy/mandown", "Python, Qt")
- Created a real-time site scraper for metadata and images to automatically download comics
- Abstracted 4 ebook creation libraries into a common comic conversion API for e-ink devices
- Implemented image caching and multiprocessing to increase download and update speeds by 300%
- Minimised regressions between release cycles by writing unit and integration tests with 55% code coverage

// #project("Kobink", "https://github.com/potatoeggy/kobink", "Rust, Axum, Postgres")
// - ??? something here (reverse engineering)
// - ??? something here (synchronisation and DB, HTTP headers)

#project("RecipeReady", "https://github.com/vincentjguo/recipeready-server", "Flutter, Selenium, FastAPI, Android")
- Scraped thousands of websites for recipes to build a database with a robust many-to-many tag system
- Designed a REST API to filter and query recipes along with ingredient pricing from Walmart

#project("\"Pillow\" Water Quality Sensor", "https://github.com/potatoeggy/ece198", "Rust, STM32")
- Created a water quality statistics aggregator and visualiser on an embedded platform in safe Rust
- Engineered an embedded system with an STM32 microcontroller, matrix keypad, and an LCD display

#project("Primoprod", "https://github.com/potatoeggy/primoprod", "Vue, TypeScript")
- Mocked a video game UI using CSS to create a hyper-realistic, cross-platform game simulator
- Constructed an extensible JSON data schema to concisely simplify adding new game content
]

= Awards

#show link: underline

- Winner of the #link("https://github.com/anyuan-chen/resketch")[EdTech category] at StormHacks 2022 from 350+ participants
- Winner of the #link("https://github.com/anyuan-chen/perdiem")[IBM Open Source category] at YRHacks 2022 from 90+ participants
- 2nd place in the Industry 4.0 2021 engineering analytics competition from 200+ participants

= Education

#indent[
#education_entry("University of Waterloo", "Candidate for B.A.Sc. in Computer Engineering", start_date: "Sep 2022", end_date: "present",
location: "Waterloo, ON", details: (
  [Secretary, Creative Writing Club],
))
]